Installing
============
WaveLink requires Python 3.8+.
You can download the latest version of Python `here <https://www.python.org/downloads/>`_.

**Windows:**

.. code:: sh

    py -3.9 -m pip install -U wavelink

**Linux:**

.. code:: sh

    python3.9 -m pip install -U wavelink


Debugging
---------
Make sure you have the latest version of Python installed, or if you prefer, a Python version of 3.8 or greater.

If you have have any other issues feel free to search for duplicates and then create a new issue on GitHub with as much detail as
possible. Including providing the output of pip, your OS details and Python version.
